<?php
/*
Fruity - A Nagios Configuration Tool
Copyright (C) 2005 Groundwork Open Source Solutions

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

include_once('includes/config.inc');

function write_service($serviceInfo) {
	global $tempHandler;
	global $fruity;
	fputs($tempHandler, "define service {\n");
	if(isset($serviceInfo['use_template_id'])) {
		fputs($tempHandler, "\tuse ".$fruity->return_service_template_name($serviceInfo['use_template_id']) . "\n");
		// Get template inherited values
		$fruity->get_service_template_inherited_servicegroups_list($serviceInfo['use_template_id'], $inherited_servicegroups);
		$fruity->get_service_template_inherited_contactgroups_list($serviceInfo['use_template_id'], $inherited_contactgroups);
		unset($serviceInfo['use_template_id']);
	}
	$fruity->return_service_servicegroups_list($serviceInfo['service_id'], $servicegroups);
	$fruity->return_service_contactgroups_list($serviceInfo['service_id'], $contactgroups);

	unset($serviceInfo['service_id']);
	unset($serviceInfo['notification_options']);
	unset($serviceInfo['stalking_options']);

	foreach($serviceInfo as $key => $value) {
		switch($key) {
			case "check_command":
				$value = $fruity->return_command_name($value);
				break;
			case "notification_period":
				$value = $fruity->return_period_name($value);
				break;
			case "event_handler":
				$value = $fruity->return_command_name($value);
				break;
			case "check_period":
				$value = $fruity->return_period_name($value);
				break;
			case "notification_options_warning":
				if($serviceInfo[$key] == 1) {
					if(isset($serviceInfo['notification_options']))
						$serviceInfo['notification_options'] .= ",";
					$serviceInfo['notification_options'] .= "w";
				}
				unset($serviceInfo[$key]);
				break;
			case "notification_options_unknown":
				if($serviceInfo[$key] == 1) {
					if(isset($serviceInfo['notification_options']))
						$serviceInfo['notification_options'] .= ",";
					$serviceInfo['notification_options'] .= "u";
				}
				unset($serviceInfo[$key]);
				break;
			case "notification_options_critical":
				if($serviceInfo[$key] == 1) {
					if(isset($serviceInfo['notification_options']))
						$serviceInfo['notification_options'] .= ",";
					$serviceInfo['notification_options'] .= "c";
				}
				unset($serviceInfo[$key]);
				break;
			case "notification_options_recovery":
				if($serviceInfo[$key] == 1) {
					if(isset($serviceInfo['notification_options']))
						$serviceInfo['notification_options'] .= ",";
					$serviceInfo['notification_options'] .= "r";
				}
				unset($serviceInfo[$key]);
				break;
			case "notification_options_flapping":
				if($serviceInfo[$key] == 1) {
					if(isset($serviceInfo['notification_options']))
						$serviceInfo['notification_options'] .= ",";
					$serviceInfo['notification_options'] .= "f";
				}
				unset($serviceInfo[$key]);
				break;
			case "stalking_options_ok":
				if($serviceInfo[$key] == 1) {
					if(isset($serviceInfo['stalking_options']))
						$serviceInfo['stalking_options'] .= ",";
					$serviceInfo['stalking_options'] .= "o";
				}
				unset($serviceInfo[$key]);
				break;
			case "stalking_options_warning":
				if($serviceInfo[$key] == 1) {
					if(isset($serviceInfo['stalking_options']))
						$serviceInfo['stalking_options'] .= ",";
					$serviceInfo['stalking_options'] .= "w";
				}
				unset($serviceInfo[$key]);
				break;
			case "stalking_options_unknown":
				if($serviceInfo[$key] == 1) {
					if(isset($serviceInfo['stalking_options']))
						$serviceInfo['stalking_options'] .= ",";
					$serviceInfo['stalking_options'] .= "u";
				}
				unset($serviceInfo[$key]);
				break;
			case "stalking_options_critical":
				if($serviceInfo[$key] == 1) {
					if(isset($serviceInfo['stalking_options']))
						$serviceInfo['stalking_options'] .= ",";
					$serviceInfo['stalking_options'] .= "c";
				}
				unset($serviceInfo[$key]);
				break;
		}
		if(isset($serviceInfo[$key]))
			fputs($tempHandler, "\t" . $key ." ".$value."\n");
	}
	if(isset($serviceInfo['notification_options']))
		fputs($tempHandler, "\tnotification_options " . $serviceInfo['notification_options'] ."\n");
	if(isset($serviceInfo['stalking_options']))
		fputs($tempHandler, "\tstalking_options " . $serviceInfo['stalking_options'] ."\n");
	// Service groups
	unset($serviceInfo['servicegroups']);
	if(count($inherited_servicegroups)) {
		foreach($inherited_servicegroups as $servicegroup) {
			if(isset($serviceInfo['servicegroups'])) {
				$serviceInfo['servicegroups'] .= ",";
			}
			$serviceInfo['servicegroups'] .= $fruity->return_servicegroup_name($servicegroup);
		}
	}
	if(count($servicegroups)) {
		foreach($servicegroups as $servicegroup) {
			if(isset($serviceInfo['servicegroups'])) {
				$serviceInfo['servicegroups'] .= ",";
			}
			$serviceInfo['servicegroups'] .= $fruity->return_servicegroup_name($servicegroup['servicegroup_id']);
		}
	}
	if(isset($serviceInfo['servicegroups']))
		fputs($tempHandler, "\tservicegroups " . $serviceInfo['servicegroups'] ."\n");
	// END Service Groups
	// Contact groups
	unset($serviceInfo['contact_groups']);
	if(count($inherited_contactgroups)) {
		foreach($inherited_contactgroups as $contactgroup) {
			if(isset($serviceInfo['contact_groups'])) {
				$serviceInfo['contact_groups'] .= ",";
			}
			$serviceInfo['contact_groups'] .= $fruity->return_contactgroup_name($contactgroup);
		}
	}
	if(count($contactgroups)) {
		foreach($contactgroups as $contactgroup) {
			if(isset($serviceInfo['contact_groups'])) {
				$serviceInfo['contact_groups'] .= ",";
			}
			$serviceInfo['contact_groups'] .= $fruity->return_contactgroup_name($contactgroup['contactgroup_id']);
		}
	}
	if(isset($serviceInfo['contact_groups']))
		fputs($tempHandler, "\tcontact_groups " . $serviceInfo['contact_groups'] ."\n");
	// END Contact Groups			
		
	
	
	fputs($tempHandler, "}\n\n"); 
}

function write_service_extinfo($tempExtendedInfo) {
	global $tempHandler;
	global $fruity;
	fputs($tempHandler, "define serviceextinfo{\n");
	fputs($tempHandler, "host_name " . $tempExtendedInfo['host_name'] . "\n");
	fputs($tempHandler, "service_description	" . $tempExtendedInfo['service_description'] . "\n");
	if($tempExtendedInfo['notes'] != '')
		fputs($tempHandler, "notes	".$tempExtendedInfo['notes'] . "\n");
	if($tempExtendedInfo['action_url'] != '')
		fputs($tempHandler, "action_url	".$tempExtendedInfo['action_url'] . "\n");
	if($tempExtendedInfo['notes_url'] != '')
		fputs($tempHandler, "notes_url	".$tempExtendedInfo['notes_url'] . "\n");
	if($tempExtendedInfo['icon_image'] != '')			
		fputs($tempHandler, "icon_image	".$tempExtendedInfo['icon_image'] . "\n");
	if($tempExtendedInfo['icon_image_alt'] != '')
		fputs($tempHandler, "icon_image_alt	".$tempExtendedInfo['icon_image_alt'] . "\n");
	fputs($tempHandler, "}\n\n");
}

function write_dependency($dependencyInfo) {
	global $tempHandler;
	global $fruity;

	if(isset($dependencyInfo['target_service_id'])) {
		fputs($tempHandler, "define servicedependency {\n");
		$fruity->get_service_info($dependencyInfo['target_service_id'], $tempServiceInfo);
		$dependencyInfo['service_description'] = $tempServiceInfo['service_description'];
		$dependencyInfo['host_name'] = $fruity->return_host_name($dependencyInfo['target_host_id']);
		unset($dependencyInfo['target_service_id']);
		// Additional Unsets
		unset($dependencyInfo['service_id']);
		unset($dependencyInfo['target_host_id']);
		unset($dependencyInfo['execution_failure_criteria_up']);
		unset($dependencyInfo['execution_failure_criteria_down']);
		unset($dependencyInfo['execution_failure_criteria_unreachable']);
		unset($dependencyInfo['notification_failure_criteria_up']);
		unset($dependencyInfo['notification_failure_criteria_down']);
		unset($dependencyInfo['notification_failure_criteria_unreachable']);
	}
	else if(isset($dependencyInfo['target_host_id'])) {
		fputs($tempHandler, "define hostdependency {\n");
		$dependencyInfo['host_name'] = $fruity->return_host_name($dependencyInfo['target_host_id']);
		unset($dependencyInfo['target_host_id']);
		
		// Additional Unsets
		unset($dependencyInfo['execution_failure_criteria_ok']);
		unset($dependencyInfo['execution_failure_criteria_warning']);
		unset($dependencyInfo['execution_failure_criteria_unknown']);
		unset($dependencyInfo['execution_failure_criteria_critical']);
		unset($dependencyInfo['notification_failure_criteria_ok']);
		unset($dependencyInfo['notification_failure_criteria_warning']);
		unset($dependencyInfo['notification_failure_criteria_unknown']);
		unset($dependencyInfo['notification_failure_criteria_critical']);
	}

	unset($dependencyInfo['dependency_id']);
	unset($dependencyInfo['execution_failure_criteria']);
	unset($dependencyInfo['notification_failure_criteria']);
	foreach($dependencyInfo as $key => $value) {
		switch($key) {
			
			case "execution_failure_criteria_up":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['execution_failure_criteria']))
						$dependencyInfo['execution_failure_criteria'] .= ",";
					$dependencyInfo['execution_failure_criteria'] .= "o";
				}
				unset($dependencyInfo[$key]);
				break;
			case "execution_failure_criteria_down":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['execution_failure_criteria']))
						$dependencyInfo['execution_failure_criteria'] .= ",";
					$dependencyInfo['execution_failure_criteria'] .= "d";
				}
				unset($dependencyInfo[$key]);
				break;
			case "execution_failure_criteria_unreachable":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['execution_failure_criteria']))
						$dependencyInfo['execution_failure_criteria'] .= ",";
					$dependencyInfo['execution_failure_criteria'] .= "u";
				}
				unset($dependencyInfo[$key]);
				break;
			case "execution_failure_criteria_pending":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['execution_failure_criteria']))
						$dependencyInfo['execution_failure_criteria'] .= ",";
					$dependencyInfo['execution_failure_criteria'] .= "p";
				}
				unset($dependencyInfo[$key]);
				break;;
			case "execution_failure_criteria_ok":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['execution_failure_criteria']))
						$dependencyInfo['execution_failure_criteria'] .= ",";
					$dependencyInfo['execution_failure_criteria'] .= "o";
				}
				unset($dependencyInfo[$key]);
				break;
			case "execution_failure_criteria_warning":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['execution_failure_criteria']))
						$dependencyInfo['execution_failure_criteria'] .= ",";
					$dependencyInfo['execution_failure_criteria'] .= "w";
				}
				unset($dependencyInfo[$key]);
				break;
			case "execution_failure_criteria_unknown":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['execution_failure_criteria']))
						$dependencyInfo['execution_failure_criteria'] .= ",";
					$dependencyInfo['execution_failure_criteria'] .= "u";
				}
				unset($dependencyInfo[$key]);
				break;
			case "execution_failure_criteria_critical":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['execution_failure_criteria']))
						$dependencyInfo['execution_failure_criteria'] .= ",";
					$dependencyInfo['execution_failure_criteria'] .= "c";
				}
				unset($dependencyInfo[$key]);
				break;
			case "notification_failure_criteria_ok":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['notification_failure_criteria']))
						$dependencyInfo['notification_failure_criteria'] .= ",";
					$dependencyInfo['notification_failure_criteria'] .= "o";
				}
				unset($dependencyInfo[$key]);
				break;
			case "notification_failure_criteria_warning":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['notification_failure_criteria']))
						$dependencyInfo['notification_failure_criteria'] .= ",";
					$dependencyInfo['notification_failure_criteria'] .= "w";
				}
				unset($dependencyInfo[$key]);
				break;
			case "notification_failure_criteria_unknown":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['notification_failure_criteria']))
						$dependencyInfo['notification_failure_criteria'] .= ",";
					$dependencyInfo['notification_failure_criteria'] .= "u";
				}
				unset($dependencyInfo[$key]);
				break;k;
			case "notification_failure_criteria_critical":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['notification_failure_criteria']))
						$dependencyInfo['notification_failure_criteria'] .= ",";
					$dependencyInfo['notification_failure_criteria'] .= "c";
				}
				unset($dependencyInfo[$key]);
				break;
			case "notification_failure_criteria_pending":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['notification_failure_criteria']))
						$dependencyInfo['notification_failure_criteria'] .= ",";
					$dependencyInfo['notification_failure_criteria'] .= "p";
				}
				unset($dependencyInfo[$key]);
				break;
			case "notification_failure_criteria_up":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['notification_failure_criteria']))
						$dependencyInfo['notification_failure_criteria'] .= ",";
					$dependencyInfo['notification_failure_criteria'] .= "o";
				}
				unset($dependencyInfo[$key]);
				break;
			case "notification_failure_criteria_down":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['notification_failure_criteria']))
						$dependencyInfo['notification_failure_criteria'] .= ",";
					$dependencyInfo['notification_failure_criteria'] .= "d";
				}
				unset($dependencyInfo[$key]);
				break;
			case "notification_failure_criteria_unreachable":
				if($dependencyInfo[$key] == 1) {
					if(isset($dependencyInfo['notification_failure_criteria']))
						$dependencyInfo['notification_failure_criteria'] .= ",";
					$dependencyInfo['notification_failure_criteria'] .= "u";
				}
				unset($dependencyInfo[$key]);
				break;

		}
		if(isset($dependencyInfo[$key]))
			fputs($tempHandler, "\t" . $key ." ".$value."\n");
	}
	if(isset($dependencyInfo['execution_failure_criteria']))
		fputs($tempHandler, "\texecution_failure_criteria " . $dependencyInfo['execution_failure_criteria'] ."\n");
	if(isset($dependencyInfo['notification_failure_criteria']))
		fputs($tempHandler, "\tnotification_failure_criteria " . $dependencyInfo['notification_failure_criteria'] ."\n");
	fputs($tempHandler, "}\n\n"); 
}

function write_escalation($escalationInfo) {
	global $tempHandler;
	global $fruity;

	if(isset($escalationInfo['service_description'])) {
		fputs($tempHandler, "define serviceescalation {\n");

		// Additional Unsets
		unset($escalationInfo['service_id']);
		unset($escalationInfo['target_host_id']);
		unset($escalationInfo['escalation_options_up']);
		unset($escalationInfo['escalation_options_down']);
		unset($escalationInfo['escalation_options_unreachable']);
	}
	else if(isset($escalationInfo['target_host_id'])) {
		fputs($tempHandler, "define hostescalation {\n");
		
		// Additional Unsets
		unset($escalationInfo['escalation_options_ok']);
		unset($escalationInfo['escalation_options_warning']);
		unset($escalationInfo['escalation_options_unknown']);
		unset($escalationInfo['escalation_options_critical']);
	}

	unset($escalationInfo['escalation_id']);
	unset($escalationInfo['escalation_options']);
	unset($escalationInfo['escalation_description']);
	foreach($escalationInfo as $key => $value) {
		switch($key) {
			case "escalation_period":
				$value = $fruity->return_period_name($value);
				break;
			
			case "escalation_options_up":
				if($escalationInfo[$key] == 1) {
					if(isset($escalationInfo['escalation_options']))
						$escalationInfo['escalation_options'] .= ",";
					$escalationInfo['escalation_options'] .= "o";
				}
				unset($escalationInfo[$key]);
				break;
			case "escalation_options_down":
				if($escalationInfo[$key] == 1) {
					if(isset($escalationInfo['escalation_options']))
						$escalationInfo['escalation_options'] .= ",";
					$escalationInfo['escalation_options'] .= "d";
				}
				unset($escalationInfo[$key]);
				break;
			case "escalation_options_unreachable":
				if($escalationInfo[$key] == 1) {
					if(isset($escalationInfo['escalation_options']))
						$escalationInfo['escalation_options'] .= ",";
					$escalationInfo['escalation_options'] .= "u";
				}
				unset($escalationInfo[$key]);
				break;
			case "escalation_options_ok":
				if($escalationInfo[$key] == 1) {
					if(isset($escalationInfo['escalation_options']))
						$escalationInfo['escalation_options'] .= ",";
					$escalationInfo['escalation_options'] .= "o";
				}
				unset($escalationInfo[$key]);
				break;
			case "escalation_options_warning":
				if($escalationInfo[$key] == 1) {
					if(isset($escalationInfo['escalation_options']))
						$escalationInfo['escalation_options'] .= ",";
					$escalationInfo['escalation_options'] .= "w";
				}
				unset($escalationInfo[$key]);
				break;
			case "escalation_options_unknown":
				if($escalationInfo[$key] == 1) {
					if(isset($escalationInfo['escalation_options']))
						$escalationInfo['escalation_options'] .= ",";
					$escalationInfo['escalation_options'] .= "u";
				}
				unset($escalationInfo[$key]);
				break;
			case "escalation_options_critical":
				if($escalationInfo[$key] == 1) {
					if(isset($escalationInfo['escalation_options']))
						$escalationInfo['escalation_options'] .= ",";
					$escalationInfo['escalation_options'] .= "c";
				}
				unset($escalationInfo[$key]);
				break;
		}
		if(isset($escalationInfo[$key]))
			fputs($tempHandler, "\t" . $key ." ".$value."\n");
	}
	if(isset($escalationInfo['escalation_options']))
		fputs($tempHandler, "\tescalation_options " . $escalationInfo['escalation_options'] ."\n");
	fputs($tempHandler, "}\n\n"); 
}




$fruity->get_main_conf($mainConfig);	// So we can get path data, for both steps.


print_header("Configuration Export");
?>
<br />
<br />
<?php
if(!isset($_GET['confirmed'])) {
	print_window_header("Warning", "80%", "center");
	?>
	Fruity is currently set to write it's configuration files to "<b><?=$mainConfig['config_dir'];?></b>", as defined 
	in Main Configuration, under Paths.  Fruity must have write access to this directory.  Fruity will also 
	attempt to create backups of existing files (if they exist) with a extension of .fruity.backup.<br />
	<br />
	<div align="center">Are you *sure* you wish to export?  This will overwrite your current nagios configuration files!<br />
	<br />
	<a href="<?=$path_config['doc_root'];?>export.php?confirmed=1">YES</a>
	<?php
	print_window_footer();
}
else if($_GET['confirmed']) {
	set_time_limit(600);	// 10 minutes should be enough for any large config.

	// First let's check for proper permissions.
	if(!@touch($mainConfig['config_dir']. "/fruitytmpfile")) {
		print_window_header("Permissions Error", NULL, "center");
		?>
		There was a problem writing to <b><?=$mainConfig['config_dir'];?></b>.  Check your 
		permissions and try again.
		<?php
		print_window_footer();
		print_footer();
		die();
	}
	else {
		unlink($mainConfig['config_dir']. "/fruitytmpfile");
	}

	$configuration_path = $mainConfig['config_dir'];
	if(isset($status_msg)) {
		?>
		<div align="center" class="statusmsg"><?=$status_msg;?></div><br />
		<?php
	}
	print_window_header("Exporting Configuration...", "80%");
	
	// BACKUP NAGIOS.CFG
	if(file_exists($configuration_path."/nagios.cfg")) {
		?>
		Backing Up nagios.cfg...
		<?php
		copy($configuration_path."/nagios.cfg", $configuration_path."/nagios.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	
	//EXPORT NAGIOS.CFG
	?>
	Exporting nagios.cfg (Main Configuration File)...
	<?php
	$tempHandler = fopen($configuration_path."/nagios.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	fputs($tempHandler, "log_file=".$mainConfig['log_file']."\n");
	fputs($tempHandler, "cfg_file=".$configuration_path."/host_templates.cfg\n");
	fputs($tempHandler, "cfg_file=".$configuration_path."/hosts.cfg\n");
	fputs($tempHandler, "cfg_file=".$configuration_path."/commands.cfg\n");
	fputs($tempHandler, "cfg_file=".$configuration_path."/timeperiods.cfg\n");
	fputs($tempHandler, "cfg_file=".$configuration_path."/contactgroups.cfg\n");
	fputs($tempHandler, "cfg_file=".$configuration_path."/contacts.cfg\n");
	fputs($tempHandler, "cfg_file=".$configuration_path."/hostgroups.cfg\n");
	fputs($tempHandler, "cfg_file=".$configuration_path."/service_templates.cfg\n");
	fputs($tempHandler, "cfg_file=".$configuration_path."/services.cfg\n");
	fputs($tempHandler, "cfg_file=".$configuration_path."/servicegroups.cfg\n");
	fputs($tempHandler, "resource_file=".$configuration_path."/resources.cfg\n");
	fputs($tempHandler, "cfg_file=".$configuration_path."/hostextinfo.cfg\n");
	fputs($tempHandler, "cfg_file=".$configuration_path."/serviceextinfo.cfg\n");
	fputs($tempHandler, "cfg_file=".$configuration_path."/dependencies.cfg\n");
	
	// No longer needed variables
	unset($mainConfig['config_dir']);
	
	foreach($mainConfig as $key => $value) {
		switch($key) {
			case "ochp_command":
				$value = $fruity->return_command_name($value);
				break;
			case "host_perfdata_command":
				$value = $fruity->return_command_name($value);
				break;
			case "service_perfdata_command":
				$value = $fruity->return_command_name($value);
				break;
			default:
			// empty
		}
		if(isset($mainConfig[$key]) && $mainConfig[$key] != '')
			fputs($tempHandler, $key ."=".$value."\n");
	}
	fclose($tempHandler);
	?><b>DONE</b><br />
	<br />
	<?php
	
	// BACKUP HOST_TEMPLATES.CFG
	if(file_exists($configuration_path."/host_templates.cfg")) {
		?>
		Backing Up host_templates.cfg...
		<?php
		copy($configuration_path."/host_templates.cfg", $configuration_path."/host_templates.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	?>
	Exporting host_templates.cfg (Host Templates Configuration File)...
	<?php
	$tempHandler = fopen($configuration_path."/host_templates.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	$fruity->get_host_template_list($template_list);
	if(count($template_list)) {
		foreach($template_list as $template) {
			$fruity->get_host_template_info($template['host_template_id'], $templateInfo);
			// Let's remove the stuff that isn't used
			unset($templateInfo['template_description']);
			
			// Get template inherited values
			$fruity->get_host_template_inherited_hostgroups_list($templateInfo['host_template_id'], $inherited_hostgroups);
			$fruity->get_host_template_inherited_contactgroups_list($templateInfo['host_template_id'], $inherited_contactgroups);
			
			unset($templateInfo['host_template_id']);
			
			fputs($tempHandler, "define host {\n");
			fputs($tempHandler, "\tname ".$templateInfo['template_name'] ."\n");
			unset($templateInfo['template_name']);
			$templateInfo['register'] = 0;
			if(isset($templateInfo['use_template_id'])) {
				fputs($tempHandler, "\tuse " . $fruity->return_host_template_name($templateInfo['use_template_id']) ."\n");
			}
			unset($templateInfo['use_template_id']);
			unset($templateInfo['notification_options']);
			unset($templateInfo['stalking_options']);
	
			foreach($templateInfo as $key => $value) {
				switch($key) {
					case "check_command":
						$value = $fruity->return_command_name($value);
						break;
					case "notification_period":
						$value = $fruity->return_period_name($value);
						break;
					case "event_handler":
						$value = $fruity->return_command_name($value);
						break;
					case "notification_options_down":
						if($templateInfo[$key] == 1) {
							if(isset($templateInfo['notification_options']))
								$templateInfo['notification_options'] .= ",";
							$templateInfo['notification_options'] .= "d";
						}
						unset($templateInfo[$key]);
						break;
					case "notification_options_unreachable":
						if($templateInfo[$key] == 1) {
							if(isset($templateInfo['notification_options']))
								$templateInfo['notification_options'] .= ",";
							$templateInfo['notification_options'] .= "u";
						}
						unset($templateInfo[$key]);
						break;
					case "notification_options_recovery":
						if($templateInfo[$key] == 1) {
							if(isset($templateInfo['notification_options']))
								$templateInfo['notification_options'] .= ",";
							$templateInfo['notification_options'] .= "r";
						}
						unset($templateInfo[$key]);
						break;
					case "stalking_options_up":
						if($templateInfo[$key] == 1) {
							if(isset($templateInfo['stalking_options']))
								$templateInfo['stalking_options'] .= ",";
							$templateInfo['stalking_options'] .= "o";
						}
						unset($templateInfo[$key]);
						break;
					case "stalking_options_down":
						if($templateInfo[$key] == 1) {
							if(isset($templateInfo['stalking_options']))
								$templateInfo['stalking_options'] .= ",";
							$templateInfo['stalking_options'] .= "d";
						}
						unset($templateInfo[$key]);
						break;
					case "stalking_options_unreachable":
						if($templateInfo[$key] == 1) {
							if(isset($templateInfo['stalking_options']))
								$templateInfo['stalking_options'] .= ",";
							$templateInfo['stalking_options'] .= "o";
						}
						unset($templateInfo[$key]);
						break;
				}
				if(isset($templateInfo[$key]))
					fputs($tempHandler, "\t" . $key ." ".$value."\n");
			}
			if(isset($templateInfo['notification_options']))
				fputs($tempHandler, "\tnotification_options " . $templateInfo['notification_options'] ."\n");
			if(isset($templateInfo['stalking_options']))
				fputs($tempHandler, "\tstalking_options " . $templateInfo['stalking_options'] ."\n");
			// Host groups
			unset($templateInfo['hostgroups']);
			if(count($inherited_hostgroups)) {
				foreach($inherited_hostgroups as $hostgroup) {
					if(isset($templateInfo['hostgroups'])) {
						$templateInfo['hostgroups'] .= ",";
					}
					$templateInfo['hostgroups'] .= $fruity->return_hostgroup_name($hostgroup);
				}
			}
			if(isset($templateInfo['hostgroups']))
				fputs($tempHandler, "\thostgroups " . $templateInfo['hostgroups'] ."\n");
			// END Host Groups
			// Contact groups
			unset($templateInfo['contact_groups']);
			if(count($inherited_contactgroups)) {
				foreach($inherited_contactgroups as $contactgroup) {
					if(isset($templateInfo['contact_groups'])) {
						$templateInfo['contact_groups'] .= ",";
					}
					$templateInfo['contact_groups'] .= $fruity->return_contactgroup_name($contactgroup);
				}
			}
			if(isset($templateInfo['contact_groups']))
				fputs($tempHandler, "\tcontact_groups " . $templateInfo['contact_groups'] ."\n");
			// END Contact Groups			
				
			
			
			fputs($tempHandler, "}\n\n"); 
			
		}
	}
	fclose($tempHandler);
	print("<b>DONE</b><br /><br />");
	
	// BACKUP HOSTS.CFG
	if(file_exists($configuration_path."/hosts.cfg")) {
		?>
		Backing Up hosts.cfg...
		<?php
		copy($configuration_path."/hosts.cfg", $configuration_path."/hosts.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	?>
	Exporting hosts.cfg (Host Configuration File)...
	<?php
	$tempHandler = fopen($configuration_path."/hosts.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	$fruity->get_host_list($host_list);
	$numOfHosts = count($host_list);
	
	for($counter = 0; $counter < $numOfHosts; $counter++) {
		$fruity->get_host_info($host_list[$counter]['host_id'], $tempHostInfo);

		fputs($tempHandler, "define host {\n");
		if(isset($tempHostInfo['use_template_id'])) {
			fputs($tempHandler, "\tuse ".$fruity->return_host_template_name($tempHostInfo['use_template_id']) . "\n");
			unset($tempHostInfo['use_template_id']);
			// Get template inherited values
			$fruity->get_host_template_inherited_hostgroups_list($tempHostInfo['use_template_id'], $inherited_hostgroups);
			$fruity->get_host_template_inherited_contactgroups_list($tempHostInfo['use_template_id'], $inherited_contactgroups);
		}
		// Now let's get our hostgroups
		unset($hostgroupList);
		unset($contactgroupList);
		$fruity->get_host_membership_list($tempHostInfo['host_id'], $hostgroupList);
		$fruity->return_host_contactgroups_list($tempHostInfo['host_id'], $contactgroupList);
		unset($tempHostInfo['host_id']);	
		unset($tempHostInfo['notification_options']);
		unset($tempHostInfo['stalking_options']);

		foreach($tempHostInfo as $key => $value) {
			switch($key) {
				case "parents":
					$value = $fruity->return_host_name($value);
					break;
				case "check_command":
					$value = $fruity->return_command_name($value);
					break;
				case "notification_period":
					$value = $fruity->return_period_name($value);
					break;
				case "event_handler":
					$value = $fruity->return_command_name($value);
					break;
				case "check_period":
					$value = $fruity->return_period_name($value);
					break;
				case "notification_options_down":
					if($tempHostInfo[$key] == 1) {
						if(isset($tempHostInfo['notification_options']))
							$tempHostInfo['notification_options'] .= ",";
						$tempHostInfo['notification_options'] .= "d";
					}
					unset($tempHostInfo[$key]);
					break;
				case "notification_options_unreachable":
					if($tempHostInfo[$key] == 1) {
						if(isset($tempHostInfo['notification_options']))
							$tempHostInfo['notification_options'] .= ",";
						$tempHostInfo['notification_options'] .= "u";
					}
					unset($tempHostInfo[$key]);
					break;
				case "notification_options_recovery":
					if($tempHostInfo[$key] == 1) {
						if(isset($tempHostInfo['notification_options']))
							$tempHostInfo['notification_options'] .= ",";
						$tempHostInfo['notification_options'] .= "r";
					}
					unset($tempHostInfo[$key]);
					break;
				case "stalking_options_up":
					if($tempHostInfo[$key] == 1) {
						if(isset($tempHostInfo['stalking_options']))
							$tempHostInfo['stalking_options'] .= ",";
						$tempHostInfo['stalking_options'] .= "o";
					}
					unset($tempHostInfo[$key]);
					break;
				case "stalking_options_down":
					if($tempHostInfo[$key] == 1) {
						if(isset($tempHostInfo['stalking_options']))
							$tempHostInfo['stalking_options'] .= ",";
						$tempHostInfo['stalking_options'] .= "d";
					}
					unset($tempHostInfo[$key]);
					break;
				case "stalking_options_unreachable":
					if($tempHostInfo[$key] == 1) {
						if(isset($tempHostInfo['stalking_options']))
							$tempHostInfo['stalking_options'] .= ",";
						$tempHostInfo['stalking_options'] .= "o";
					}
					unset($tempHostInfo[$key]);
					break;
			}
			if(isset($tempHostInfo[$key]))
				fputs($tempHandler, "\t" . $key ." ".$value."\n");
		}
		if(isset($tempHostInfo['notification_options']))
			fputs($tempHandler, "\tnotification_options " . $tempHostInfo['notification_options'] ."\n");
		if(isset($tempHostInfo['stalking_options']))
			fputs($tempHandler, "\tstalking_options " . $tempHostInfo['stalking_options'] ."\n");
		// Host groups
		unset($tempHostInfo['hostgroups']);
		unset($tempHostGroups);
		// First check for inherited host groups
		if(count($inherited_hostgroups)) {
			foreach($inherited_hostgroups as $hostgroup) {
					$tempHostGroups[] = $fruity->return_hostgroup_name($hostgroup);
			}
		}
		if(count($hostgroupList)) {
			foreach($hostgroupList as $hostgroup) {
					if(!is_array($tempHostGroups) || !in_array($hostgroup, $tempHostGroups))
						$tempHostGroups[] = $fruity->return_hostgroup_name($hostgroup['hostgroup_id']);
			}
		}
		if(count($tempHostGroups)) {
			foreach($tempHostGroups as $hostgroup) {
				if(isset($tempHostInfo['hostgroups']))
					$tempHostInfo['hostgroups'] .= ",";
				$tempHostInfo['hostgroups'] .= $hostgroup;
			}
		}
		
		if(isset($tempHostInfo['hostgroups']))
			fputs($tempHandler, "\thostgroups " . $tempHostInfo['hostgroups'] ."\n");
		// END Host Groups	
		
		// Contact groups
		unset($tempHostInfo['contactgroups']);
		unset($tempContactGroups);
		// First check for inherited host groups
		if(count($inherited_contactgroups)) {
			foreach($inherited_contactgroups as $contactgroup) {
					$tempContactGroups[] = $fruity->return_contactgroup_name($contactgroup);
			}
		}
		if(count($contactgroupList)) {
			foreach($contactgroupList as $contactgroup) {
					if(!is_array($tempContactGroups) || !in_array($contactgroup, $tempContactGroups))
						$tempContactGroups[] = $fruity->return_contactgroup_name($contactgroup['contactgroup_id']);
			}
		}
		if(count($tempContactGroups)) {
			foreach($tempContactGroups as $contactgroup) {
				if(isset($tempHostInfo['contact_groups']))
					$tempHostInfo['contact_groups'] .= ",";
				$tempHostInfo['contact_groups'] .= $contactgroup;
			}
		}
		
		if(isset($tempHostInfo['contact_groups']))
			fputs($tempHandler, "\tcontact_groups " . $tempHostInfo['contact_groups'] ."\n");
		// END Contact Groups	
			
			
		fputs($tempHandler, "}\n\n"); 
		
	}
	fclose($tempHandler);
	print("<b>DONE</b><br /><br />");
	?>
	<br />
	<?php
	// BACKUP COMMANDS.CFG
	if(file_exists($configuration_path."/commands.cfg")) {
		?>
		Backing Up commands.cfg...
		<?php
		copy($configuration_path."/commands.cfg", $configuration_path."/commands.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	?>
	Exporting commands.cfg (Commands Configuration File)...
	<?php
	$tempHandler = fopen($configuration_path."/commands.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	$fruity->return_command_list($command_list);
	$numOfCommands = count($command_list);
	for($counter = 0; $counter < $numOfCommands; $counter++) {
		$fruity->get_command($command_list[$counter]['command_id'], $tempCommandInfo);
		fputs($tempHandler, "define command{\n");
		fputs($tempHandler, "command_name	".$tempCommandInfo['command_name']."\n");
		fputs($tempHandler, "command_line	".$tempCommandInfo['command_line']."\n");
		fputs($tempHandler, "}\n\n");
	}
	fclose($tempHandler);
	?><b>DONE</b><br />
	<br />
	<?php

	// BACKUP TIMEPERIODS.CFG
	if(file_exists($configuration_path."/timeperiods.cfg")) {
		?>
		Backing Up timeperiods.cfg...
		<?php
		copy($configuration_path."/timeperiods.cfg", $configuration_path."/timeperiods.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	?>
	Exporting timeperiods.cfg (Time Periods Configuration File)...
	<?php
	$tempHandler = fopen($configuration_path."/timeperiods.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	$fruity->return_period_list($period_list);
	$numOfPeriods = count($period_list);
	for($counter = 0; $counter < $numOfPeriods; $counter++) {
		$fruity->get_period($period_list[$counter]['timeperiod_id'], $tempPeriodInfo);
		fputs($tempHandler, "define timeperiod{\n");
		fputs($tempHandler, "timeperiod_name	".$tempPeriodInfo['timeperiod_name']."\n");
		fputs($tempHandler, "alias	".$tempPeriodInfo['alias']."\n");
		if($tempPeriodInfo['sunday'])
			fputs($tempHandler, "sunday	".$tempPeriodInfo['sunday']."\n");
		if($tempPeriodInfo['monday'])
			fputs($tempHandler, "monday	".$tempPeriodInfo['monday']."\n");
		if($tempPeriodInfo['tuesday'])
			fputs($tempHandler, "tuesday	".$tempPeriodInfo['tuesday']."\n");
		if($tempPeriodInfo['wednesday'])
			fputs($tempHandler, "wednesday	".$tempPeriodInfo['wednesday']."\n");
		if($tempPeriodInfo['thursday'])
			fputs($tempHandler, "thursday	".$tempPeriodInfo['thursday']."\n");
		if($tempPeriodInfo['friday'])
			fputs($tempHandler, "friday	".$tempPeriodInfo['friday']."\n");
		if($tempPeriodInfo['saturday'])
			fputs($tempHandler, "saturday	".$tempPeriodInfo['saturday']."\n");
		fputs($tempHandler, "}\n\n");
	}
	fclose($tempHandler);
	?><b>DONE</b><br />
	<br />
	<?php
	// BACKUP CONTACTGROUPS.CFG
	if(file_exists($configuration_path."/contactgroups.cfg")) {
		?>
		Backing Up contactgroups.cfg...
		<?php
		copy($configuration_path."/contactgroups.cfg", $configuration_path."/contactgroups.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	?>
	Exporting contactgroups.cfg (Contact Groups Configuration File)...
	<?php
	$tempHandler = fopen($configuration_path."/contactgroups.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	$fruity->get_contactgroup_list($group_list);
	$numOfGroups = count($group_list);
	for($counter = 0; $counter < $numOfGroups; $counter++) {
		$fruity->get_contactgroup_info($group_list[$counter]['contactgroup_id'], $tempGroupInfo);
		fputs($tempHandler, "define contactgroup{\n");
		fputs($tempHandler, "contactgroup_name	".$tempGroupInfo['contactgroup_name']."\n");
		fputs($tempHandler, "alias	".$tempGroupInfo['alias']."\n");
		fputs($tempHandler, "members	");
		$fruity->return_contactgroup_member_list($group_list[$counter]['contactgroup_id'], $memberList);
		$numOfMembers = count($memberList);	
		for($subcounter = 0; $subcounter < $numOfMembers; $subcounter++ ) {
			if($subcounter)
				fputs($tempHandler,",");
			fputs($tempHandler,$fruity->return_contact_name($memberList[$subcounter]['contact_id']));
		}
		fputs($tempHandler, "\n}\n\n");
	}
	fclose($tempHandler);
	?><b>DONE</b><br />
	<br />
	<?php
	// BACKUP CONTACTS.CFG
	if(file_exists($configuration_path."/contacts.cfg")) {
		?>
		Backing Up contacts.cfg...
		<?php
		copy($configuration_path."/contacts.cfg", $configuration_path."/contacts.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	?>
	Exporting contacts.cfg (Contacts Configuration File)...
	<?php
	$tempHandler = fopen($configuration_path."/contacts.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	$fruity->get_contact_list($contact_list);
	$numOfContacts = count($contact_list);
	for($counter = 0; $counter < $numOfContacts; $counter++) {
		$fruity->get_contact_info($contact_list[$counter]['contact_id'], $tempContactInfo);
		fputs($tempHandler, "define contact{\n");
		fputs($tempHandler, "contact_name	".$tempContactInfo['contact_name']."\n");
		fputs($tempHandler, "alias	".$tempContactInfo['alias']."\n");
		fputs($tempHandler, "host_notification_period	".$fruity->return_period_name($tempContactInfo['host_notification_period'])."\n");
		fputs($tempHandler, "service_notification_period	".$fruity->return_period_name($tempContactInfo['service_notification_period'])."\n");

		fputs($tempHandler, "host_notification_options	");
		if(!$tempContactInfo['host_notification_options_down'] && !$tempContactInfo['host_notification_options_unreachable'] && !$tempContactInfo['host_notification_options_recovery']) {
			fputs($tempHandler, "n");
		}
		else {
			if($tempContactInfo['host_notification_options_down']) {
				fputs($tempHandler, "d");
				if($tempContactInfo['host_notification_options_unreachable'] || $tempContactInfo['host_notification_options_recovery'])
					fputs($tempHandler, ",");
			}
			if($tempContactInfo['host_notification_options_unreachable']) {
				fputs($tempHandler, "u");
				if($tempContactInfo['host_notification_options_recovery'])
					fputs($tempHandler, ",");
			}
			if($tempContactInfo['host_notification_options_recovery']) {
				fputs($tempHandler, "r");
			}
		}
		fputs($tempHandler,"\n");
		
		fputs($tempHandler, "service_notification_options	");
		if(!$tempContactInfo['service_notification_options_warning'] && !$tempContactInfo['service_notification_options_unknown'] && !$tempContactInfo['service_notification_options_critical'] && !$tempContactInfo['service_notification_options_recovery']) {
			fputs($tempHandler, "n");
		}
		else {
			if($tempContactInfo['service_notification_options_warning']) {
				fputs($tempHandler, "w");
				if($tempContactInfo['service_notification_options_unknown'] || $tempContactInfo['service_notification_options_critical'] || $tempContactInfo['service_notification_options_recovery'])
					fputs($tempHandler, ",");
			}
			if($tempContactInfo['service_notification_options_unknown']) {
				fputs($tempHandler, "u");
				if($tempContactInfo['service_notification_options_critical'] || $tempContactInfo['service_notification_options_recovery'])
					fputs($tempHandler, ",");
			}
			if($tempContactInfo['service_notification_options_critical']) {
				fputs($tempHandler, "c");
				if($tempContactInfo['service_notification_options_recovery'])
					fputs($tempHandler, ",");
			}
			if($tempContactInfo['service_notification_options_recovery']) {
				fputs($tempHandler, "r");
			}		}
		fputs($tempHandler,"\n");
		
		$fruity->get_contacts_notification_commands($contact_list[$counter]['contact_id'], $notification_list);
		$numOfHostCommands = count($notification_list['host']);
		if($numOfHostCommands) {
			fputs($tempHandler, "host_notification_commands	");
			for($subcounter = 0; $subcounter < $numOfHostCommands; $subcounter++) {
				if($subcounter)
					fputs($tempHandler,",");
				fputs($tempHandler,$fruity->return_command_name($notification_list['host'][$subcounter]['command_id']));
			}
			fputs($tempHandler, "\n");
		}
		$numOfServiceCommands = count($notification_list['service']);
		if($numOfServiceCommands) {
			fputs($tempHandler, "service_notification_commands ");
			for($subcounter = 0; $subcounter < $numOfServiceCommands; $subcounter++) {
				if($subcounter)
					fputs($tempHandler,",");
				fputs($tempHandler,$fruity->return_command_name($notification_list['service'][$subcounter]['command_id']));
			}
			fputs($tempHandler, "\n");
		}
		if($tempContactInfo['email'])
			fputs($tempHandler, "email	".$tempContactInfo['email']."\n");
		if($tempContactInfo['pager'])			
			fputs($tempHandler, "pager	".$tempContactInfo['pager']."\n");
		$fruity->get_contact_addresses($contact_list[$counter]['contact_id'], $contactAddresses);
		$numOfAddresses = count($contactAddresses);
		for($subcounter = 0; $subcounter < $numOfAddresses; $subcounter++) {
			fputs($tempHandler, "address".($subcounter+1)."	".$contactAddresses[$subcounter]['address']."\n");
		}
		fputs($tempHandler, "}\n\n");
	}
	fclose($tempHandler);
	?><b>DONE</b><br />
	<br />
	<?php

	// BACKUP HOSTGROUPS.CFG
	if(file_exists($configuration_path."/hostgroups.cfg")) {
		?>
		Backing Up hostgroups.cfg...
		<?php
		copy($configuration_path."/hostgroups.cfg", $configuration_path."/hostgroups.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	?>
	Exporting hostgroups.cfg (Host Groups Configuration File)...
	<?php
	$tempHandler = fopen($configuration_path."/hostgroups.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	$fruity->get_hostgroup_list($group_list);
	$numOfGroups = count($group_list);
	for($counter = 0; $counter < $numOfGroups; $counter++) {
		$fruity->get_hostgroup_info($group_list[$counter]['hostgroup_id'], $tempGroupInfo);
		fputs($tempHandler, "define hostgroup{\n");
		fputs($tempHandler, "hostgroup_name	".$tempGroupInfo['hostgroup_name']."\n");
		fputs($tempHandler, "alias	".$tempGroupInfo['alias']."\n");
		/* WE DON'T DO HOSTGROUP CONTACT_GROUPS ANYMORE FOR VERSION 2 OF NAGIOS
		fputs($tempHandler, "contact_groups	");
		$fruity->return_hostgroup_contactgroups_list($group_list[$counter]['hostgroup_id'], $contactgroups_list);
		$numOfMembers = count($contactgroups_list);	
		for($subcounter = 0; $subcounter < $numOfMembers; $subcounter++ ) {
			if($subcounter)
				fputs($tempHandler,",");
			fputs($tempHandler,$fruity->return_contactgroup_name($contactgroups_list[$subcounter]['contactgroup_id']));
		}
		*/
		fputs($tempHandler, "\n");
		fputs($tempHandler, "}\n\n");
	}
	fclose($tempHandler);
	?><b>DONE</b><br />
	<br />
	<?php
	// BACKUP SERVICE_TEMPLATES.CFG
	if(file_exists($configuration_path."/service_templates.cfg")) {
		?>
		Backing Up service_templates.cfg...
		<?php
		copy($configuration_path."/service_templates.cfg", $configuration_path."/service_templates.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	?>
	Exporting service_templates.cfg (Service Templates Configuration File)...
	<?php
	$tempHandler = fopen($configuration_path."/service_templates.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	$fruity->get_service_template_list($template_list);
	if(count($template_list)) {
		foreach($template_list as $template) {
			$fruity->get_service_template_info($template['service_template_id'], $templateInfo);
			// Let's remove the stuff that isn't used
			unset($templateInfo['template_description']);
			
			// Get template inherited values
			$fruity->get_service_template_inherited_servicegroups_list($templateInfo['service_template_id'], $inherited_servicegroups);
			$fruity->get_service_template_inherited_contactgroups_list($templateInfo['service_template_id'], $inherited_contactgroups);
			
			unset($templateInfo['service_template_id']);
			
			fputs($tempHandler, "define service {\n");
			fputs($tempHandler, "\tname ".$templateInfo['template_name'] ."\n");
			unset($templateInfo['template_name']);
			$templateInfo['register'] = 0;
			if(isset($templateInfo['use_template_id'])) {
				fputs($tempHandler, "\tuse " . $fruity->return_service_template_name($templateInfo['use_template_id']) ."\n");
			}
			unset($templateInfo['use_template_id']);
			unset($templateInfo['notification_options']);
			unset($templateInfo['stalking_options']);
	
			foreach($templateInfo as $key => $value) {
				switch($key) {
					case "check_command":
						$value = $fruity->return_command_name($value);
						break;
					case "notification_period":
							$value = $fruity->return_period_name($value);
						break;
					case "event_handler":
						$value = $fruity->return_command_name($value);
						break;
					case "check_period":
						$value = $fruity->return_period_name($value);
						break;
					case "notification_options_warning":
						if($templateInfo[$key] == 1) {
							if(isset($templateInfo['notification_options']))
								$templateInfo['notification_options'] .= ",";
							$templateInfo['notification_options'] .= "w";
						}
						unset($templateInfo[$key]);
						break;
					case "notification_options_unknown":
						if($templateInfo[$key] == 1) {
							if(isset($templateInfo['notification_options']))
								$templateInfo['notification_options'] .= ",";
							$templateInfo['notification_options'] .= "u";
						}
						unset($templateInfo[$key]);
						break;
					case "notification_options_critical":
						if($templateInfo[$key] == 1) {
							if(isset($templateInfo['notification_options']))
								$templateInfo['notification_options'] .= ",";
							$templateInfo['notification_options'] .= "c";
						}
						unset($templateInfo[$key]);
						break;
					case "notification_options_recovery":
						if($templateInfo[$key] == 1) {
							if(isset($templateInfo['notification_options']))
								$templateInfo['notification_options'] .= ",";
							$templateInfo['notification_options'] .= "r";
						}
						unset($templateInfo[$key]);
						break;
					case "notification_options_flapping":
						if($templateInfo[$key] == 1) {
							if(isset($templateInfo['notification_options']))
								$templateInfo['notification_options'] .= ",";
							$templateInfo['notification_options'] .= "f";
						}
						unset($templateInfo[$key]);
						break;
					case "stalking_options_ok":
						if($templateInfo[$key] == 1) {
							if(isset($templateInfo['stalking_options']))
								$templateInfo['stalking_options'] .= ",";
							$templateInfo['stalking_options'] .= "o";
						}
						unset($templateInfo[$key]);
						break;
					case "stalking_options_warning":
						if($templateInfo[$key] == 1) {
							if(isset($templateInfo['stalking_options']))
								$templateInfo['stalking_options'] .= ",";
							$templateInfo['stalking_options'] .= "w";
						}
						unset($templateInfo[$key]);
						break;
					case "stalking_options_unknown":
						if($templateInfo[$key] == 1) {
							if(isset($templateInfo['stalking_options']))
								$templateInfo['stalking_options'] .= ",";
							$templateInfo['stalking_options'] .= "u";
						}
						unset($templateInfo[$key]);
						break;
					case "stalking_options_critical":
						if($templateInfo[$key] == 1) {
							if(isset($templateInfo['stalking_options']))
								$templateInfo['stalking_options'] .= ",";
							$templateInfo['stalking_options'] .= "c";
						}
						unset($templateInfo[$key]);
						break;
				}
				if(isset($templateInfo[$key]))
					fputs($tempHandler, "\t" . $key ." ".$value."\n");
			}
			if(isset($templateInfo['notification_options']))
				fputs($tempHandler, "\tnotification_options " . $templateInfo['notification_options'] ."\n");
			if(isset($templateInfo['stalking_options']))
				fputs($tempHandler, "\tstalking_options " . $templateInfo['stalking_options'] ."\n");
			// Service groups
			unset($templateInfo['servicegroups']);
			if(count($inherited_servicegroups)) {
				foreach($inherited_servicegroups as $servicegroup) {
					if(isset($templateInfo['servicegroups'])) {
						$templateInfo['servicegroups'] .= ",";
					}
					$templateInfo['servicegroups'] .= $fruity->return_servicegroup_name($servicegroup);
				}
			}
			if(isset($templateInfo['servicegroups']))
				fputs($tempHandler, "\tservicegroups " . $templateInfo['servicegroups'] ."\n");
			// END Service Groups
			// Contact groups
			unset($templateInfo['contact_groups']);
			if(count($inherited_contactgroups)) {
				foreach($inherited_contactgroups as $contactgroup) {
					if(isset($templateInfo['contact_groups'])) {
						$templateInfo['contact_groups'] .= ",";
					}
					$templateInfo['contact_groups'] .= $fruity->return_contactgroup_name($contactgroup);
				}
			}
			if(isset($templateInfo['contact_groups']))
				fputs($tempHandler, "\tcontact_groups " . $templateInfo['contact_groups'] ."\n");
			// END Contact Groups			
				
			
			
			fputs($tempHandler, "}\n\n"); 
			
		}
	}
	fclose($tempHandler);
	print("<b>DONE</b><br /><br />");
	
	// BACKUP SERVICES.CFG
	if(file_exists($configuration_path."/services.cfg")) {
		?>
		Backing Up services.cfg...
		<?php
		copy($configuration_path."/services.cfg", $configuration_path."/services.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	?>
	Exporting services.cfg (Services Configuration File)...
	<?php
	$tempHandler = fopen($configuration_path."/services.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	$fruity->get_services_list($services_list);
	foreach($services_list as $service) {
		unset($serviceInfo);
		$fruity->get_service_info($service['service_id'], $serviceInfo);
		if(isset($serviceInfo['host_id'])) {	// We're for a host
			$serviceInfo['host_name'] = $fruity->return_host_name($serviceInfo['host_id']);
			unset($serviceInfo['host_id']);
			write_service($serviceInfo);
		}
		else if(isset($serviceInfo['hostgroup_id'])) {	// We're for a hostgroup
			$serviceInfo['hostgroup_name'] = $fruity->return_hostgroup_name($serviceInfo['hostgroup_id']);
			unset($serviceInfo['hostgroup_id']);
			write_service($serviceInfo);
		}
		else if(isset($serviceInfo['host_template_id'])) {	// Uh oh, we've got a service for a host template! AIYEE
			// We need to get a list of hosts which are affected by this template
			$fruity->get_hosts_affected_by_host_template($serviceInfo['host_template_id'], $affectedHosts);
			unset($serviceInfo['host_template_id']);
			if(count($affectedHosts)) {
				foreach($affectedHosts as $host_id) {
					$serviceInfo['host_name'] = $fruity->return_host_name($host_id);
					write_service($serviceInfo);
				}
			}
		}
		
	}
	fclose($tempHandler);
	print("<b>DONE</b><br /><br />");
	
	// BACKUP SERVICEGROUPS.CFG
	if(file_exists($configuration_path."/servicegroups.cfg")) {
		?>
		Backing Up servicegroups.cfg...
		<?php
		copy($configuration_path."/servicegroups.cfg", $configuration_path."/servicegroups.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	?>
	Exporting servicegroups.cfg (Service Groups Configuration File)...
	<?php
	$tempHandler = fopen($configuration_path."/servicegroups.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	$fruity->get_servicegroup_list($group_list);
	$numOfGroups = count($group_list);
	for($counter = 0; $counter < $numOfGroups; $counter++) {
		$fruity->get_servicegroup_info($group_list[$counter]['servicegroup_id'], $tempGroupInfo);
		fputs($tempHandler, "define servicegroup{\n");
		fputs($tempHandler, "servicegroup_name	".$tempGroupInfo['servicegroup_name']."\n");
		if($tempGroupInfo['alias'] != '')
			fputs($tempHandler, "alias	".$tempGroupInfo['alias']."\n");
		fputs($tempHandler, "\n");
		fputs($tempHandler, "}\n\n");
	}
	fclose($tempHandler);
	?><b>DONE</b><br />
	<br />
	<?php
	$fruity->get_cgi_conf($cgi_config);

	// BACKUP CGI.CFG
	if(file_exists($configuration_path."/cgi.cfg")) {
		?>
		Backing Up cgi.cfg...
		<?php
		copy($configuration_path."/cgi.cfg", $configuration_path."/cgi.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	
	//EXPORT NAGIOS.CFG
	?>
	Exporting cgi.cfg (CGI Configuration File)...
	<?php
	$tempHandler = fopen($configuration_path."/cgi.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	fputs($tempHandler, "main_config_file=".$configuration_path."/nagios.cfg\n");
	fputs($tempHandler, "resource_file=".$configuration_path."/resources.cfg\n");
	// No longer needed variables
	
	foreach($cgi_config as $key => $value) {
		switch($key) {
			default:
			// empty
		}
		if(isset($cgi_config[$key]) && $cgi_config[$key] != '')
			fputs($tempHandler, $key ."=".$value."\n");
	}
	fclose($tempHandler);
	?><b>DONE</b><br />
	<br />
	<?php

	// BACKUP RESOURCES.CFG
	if(file_exists($configuration_path."/resources.cfg")) {
		?>
		Backing Up resources.cfg...
		<?php
		copy($configuration_path."/resources.cfg", $configuration_path."/resources.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	?>
	Exporting resources.cfg (Resources Configuration File)...
	<?php
	$tempHandler = fopen($configuration_path."/resources.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	$fruity->get_resource_conf($resource_config);
	for($counter = 1; $counter <= 32; $counter++) {
		if($resource_config['user'.$counter] != '')
			fputs($tempHandler, "\$USER".$counter."\$=".$resource_config['user'.$counter]."\n");
	}
	fclose($tempHandler);
	?><b>DONE</b><br />
	<br />
	<?php

	// BACKUP hostextinfo.CFG
	if(file_exists($configuration_path."/hostextinfo.cfg")) {
		?>
		Backing Up hostextinfo.cfg...
		<?php
		copy($configuration_path."/hostextinfo.cfg", $configuration_path."/hostextinfo.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	?>
	Exporting hostextinfo.cfg (Host Extended Information File)...
	<?php
	$tempHandler = fopen($configuration_path."/hostextinfo.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	$fruity->get_host_list($host_list);
	$numOfHosts = count($host_list);
	for($counter = 0; $counter < $numOfHosts; $counter++) {
		unset($tempHostInfo);
		$fruity->get_host_extended_info($host_list[$counter]['host_id'], $tempExtendedInfo);
		$fruity->get_host_info($host_list[$counter]['host_id'], $tempHostInfo);
		if(isset($tempHostInfo['use_template_id'])) {	// Oh noes, we've gots the template!
				$result = $fruity->get_inherited_host_template_extended_values($tempHostInfo['use_template_id'], $tempInheritedValues, $tempInheritedValuesSources);
				if(count($tempInheritedValues))
				foreach($tempInheritedValues as $key=>$value) {
					if(isset($tempInheritedValues[$key]) && !isset($tempExtendedInfo[$key])) {
						$tempExtendedInfo[$key] = $value;
					}
				}
		}
			fputs($tempHandler, "define hostextinfo{\n");	
			fputs($tempHandler, "host_name	".$fruity->return_host_name($host_list[$counter]['host_id']) . "\n");
			if($tempExtendedInfo['notes'] != '')
				fputs($tempHandler, "notes	".$tempExtendedInfo['notes'] . "\n");
			if($tempExtendedInfo['action_url'] != '')
				fputs($tempHandler, "action_url	".$tempExtendedInfo['action_url'] . "\n");
			if($tempExtendedInfo['notes_url'] != '')
				fputs($tempHandler, "notes_url	".$tempExtendedInfo['notes_url'] . "\n");
			if($tempExtendedInfo['icon_image'] != '')			
				fputs($tempHandler, "icon_image	".$tempExtendedInfo['icon_image'] . "\n");
			if($tempExtendedInfo['icon_image_alt'] != '')
				fputs($tempHandler, "icon_image_alt	".$tempExtendedInfo['icon_image_alt'] . "\n");
			if($tempExtendedInfo['vrml_image'] != '')
				fputs($tempHandler, "vrml_image	".$tempExtendedInfo['vrml_image'] . "\n");
			if($tempExtendedInfo['statusmap_image'] != '')
				fputs($tempHandler, "statusmap_image	".$tempExtendedInfo['statusmap_image'] . "\n");
			if($tempExtendedInfo['two_d_coords'] != '')
				fputs($tempHandler, "2d_coords	".$tempExtendedInfo['two_d_coords'] . "\n");
			if($tempExtendedInfo['three_d_coords'] != '')
				fputs($tempHandler, "3d_coords	".$tempExtendedInfo['three_d_coords'] . "\n");
			fputs($tempHandler, "}\n\n");
	}
	fclose($tempHandler);
	?><b>DONE</b><br />
	<br />	
	<?php
	
	// BACKUP serviceextinfo.CFG
	if(file_exists($configuration_path."/serviceextinfo.cfg")) {
		?>
		Backing Up serviceextinfo.cfg...
		<?php
		copy($configuration_path."/serviceextinfo.cfg", $configuration_path."/serviceextinfo.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	?>
	Exporting serviceextinfo.cfg (Service Extended Information File)...
	<?php
	$tempHandler = fopen($configuration_path."/serviceextinfo.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	$fruity->get_services_list($service_list);
	$numOfServices = count($service_list);
	for($counter = 0; $counter < $numOfServices; $counter++) {
		$fruity->get_service_extended_info($service_list[$counter]['service_id'], $tempExtendedInfo);
		$fruity->get_service_info($service_list[$counter]['service_id'], $tempServiceInfo);
		if(isset($tempServiceInfo['use_template_id'])) {	// Oh noes, we've gots the template!
				$result = $fruity->get_inherited_service_template_extended_values($tempServiceInfo['use_template_id'], $tempInheritedValues, $tempInheritedValuesSources);
				if(count($tempInheritedValues))
				foreach($tempInheritedValues as $key=>$value) {
					if(isset($tempInheritedValues[$key]) && !isset($tempExtendedInfo[$key])) {
						$tempExtendedInfo[$key] = $value;
					}
				}
		}
		$tempExtendedInfo['service_description'] = $tempServiceInfo['service_description'];
		if(isset($tempServiceInfo['host_id'])) {	// We're for a host
			$tempExtendedInfo['host_name'] = $fruity->return_host_name($tempServiceInfo['host_id']);
			unset($serviceInfo['host_id']);
			write_service_extinfo($tempExtendedInfo);
		}
		else if(isset($tempServiceInfo['hostgroup_id'])) {	// We're for a hostgroup
			$fruity->return_hostgroup_member_list($tempServiceInfo['hostgroup_id'], $affectedHosts);
			if(count($affectedHosts)) {
				foreach($affectedHosts as $host) {
					unset($tempExtendedInfo['host_name']);
					$tempExtendedInfo['host_name'] = $fruity->return_host_name($host['host_id']);
					if(isset($tempExtendedInfo['host_name']))
						write_service_extinfo($tempExtendedInfo);
				}
			}
		}
		else if(isset($tempServiceInfo['host_template_id'])) {	// Uh oh, we've got a service for a host template! AIYEE
			// We need to get a list of hosts which are affected by this template
			$affectedHosts = NULL;
			$fruity->get_hosts_affected_by_host_template($tempServiceInfo['host_template_id'], $affectedHosts);
			unset($tempServiceInfo['host_template_id']);
			if(count($affectedHosts)) {
				foreach($affectedHosts as $host_id) {
					$tempExtendedInfo['host_name'] = $fruity->return_host_name($host_id);
					write_service_extinfo($tempExtendedInfo);
				}
			}
		}
	}
	fclose($tempHandler);
	?><b>DONE</b><br />
	<br />
	<?php
	
	// BACKUP DEPENDENCIES.CFG
	if(file_exists($configuration_path."/dependencies.cfg")) {
		?>
		Backing Up dependencies.cfg...
		<?php
		copy($configuration_path."/dependencies.cfg", $configuration_path."/dependencies.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	?>
	Exporting dependencies.cfg (Dependencies Configuration File)...
	<?php
	$tempHandler = fopen($configuration_path."/dependencies.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	$fruity->get_dependencies_list($dependencies_list);
	if(count($dependencies_list)) {
		foreach($dependencies_list as $dependency) {
			unset($serviceInfo);
			unset($dependencyInfo['dependent_host_name']);
			unset($dependencyInfo['dependent_service_description']);
			$fruity->get_dependency($dependency['dependency_id'], $dependencyInfo);
			if(isset($dependencyInfo['host_id'])) {	// We're for a host
				$dependencyInfo['dependent_host_name'] = $fruity->return_host_name($dependencyInfo['host_id']);
				unset($dependencyInfo['host_id']);
				write_dependency($dependencyInfo);
			}
			else if(isset($dependencyInfo['host_template_id'])) {	// Uh oh, we've got a depoendency for a host template! AIYEE
				// We need to get a list of hosts which are affected by this template
				$fruity->get_hosts_affected_by_host_template($dependencyInfo['host_template_id'], $affectedHosts);
				unset($dependencyInfo['host_template_id']);
				if(count($affectedHosts)) {
					foreach($affectedHosts as $host_id) {
						$dependencyInfo['dependent_host_name'] = $fruity->return_host_name($host_id);
						write_dependency($dependencyInfo);
					}
				}
			}
			else if(isset($dependencyInfo['service_template_id'])) {
				// We need to get a list of hosts which are affected by this template
				// First get a list of services which are effected
				$fruity->get_services_affected_by_service_template($dependencyInfo['service_template_id'], $affectedServices);
				unset($dependencyInfo['service_template_id']);
				if(count($affectedServices)) {
					foreach($affectedServices as $service_id) {
						unset($serviceInfo);
						unset($dependencyInfo['dependent_host_name']);
						unset($dependencyInfo['dependent_service_description']);
						$fruity->get_service_info($service['service_id'], $serviceInfo);
						if(isset($serviceInfo['host_id'])) {	// We're for a host
							$dependencyInfo['dependent_host_name'] = $fruity->return_host_name($serviceInfo['host_id']);
							$dependencyInfo['dependent_service_description'] = $serviceInfo['service_description'];
							write_dependency($dependencyInfo);
						}
						else if(isset($serviceInfo['hostgroup_id'])) {	// We're for a hostgroup
							$dependencyInfo['dependent_hostgroup_name'] = $fruity->return_hostgroup_name($serviceInfo['hostgroup_id']);
							$dependencyInfo['dependent_service_description'] = $serviceInfo['service_description'];
							unset($serviceInfo['hostgroup_id']);
							write_dependency($dependencyInfo);
						}
						else if(isset($serviceInfo['host_template_id'])) {	// Uh oh, we've got a service for a host template! AIYEE
							// We need to get a list of hosts which are affected by this template
							$fruity->get_hosts_affected_by_host_template($serviceInfo['host_template_id'], $affectedHosts);
							$dependencyInfo['dependent_service_description'] = $serviceInfo['service_description'];
							unset($serviceInfo['host_template_id']);
							if(count($affectedHosts)) {
								foreach($affectedHosts as $host_id) {
									$dependencyInfo['dependent_host_name'] = $fruity->return_host_name($host_id);
									write_dependency($dependencyInfo);
								}
							}
						}
					}
				}
			}
			else if(isset($dependencyInfo['service_id'])) {
				$fruity->get_service_info($dependencyInfo['service_id'], $serviceInfo);
				$dependencyInfo['dependent_service_description'] = $serviceInfo['service_description'];
				if(isset($serviceInfo['host_id'])) {	// We're for a host
					$dependencyInfo['dependent_host_name'] = $fruity->return_host_name($serviceInfo['host_id']);
					unset($serviceInfo['host_id']);
					write_dependency($serviceInfo);
				}
				else if(isset($serviceInfo['hostgroup_id'])) {	// We're for a hostgroup
					$dependencyInfo['dependent_hostgroup_name'] = $fruity->return_hostgroup_name($serviceInfo['hostgroup_id']);
					unset($serviceInfo['hostgroup_id']);
					write_dependency($serviceInfo);
				}
				else if(isset($serviceInfo['host_template_id'])) {	// Uh oh, we've got a service for a host template! AIYEE
					// We need to get a list of hosts which are affected by this template
					$fruity->get_hosts_affected_by_host_template($serviceInfo['host_template_id'], $affectedHosts);
					$dependencyInfo['dependent_service_description'] = $serviceInfo['service_description'];
					unset($serviceInfo['host_template_id']);
					if(count($affectedHosts)) {
						foreach($affectedHosts as $host_id) {
							$dependencyInfo['dependent_host_name'] = $fruity->return_host_name($host_id);
							write_dependency($dependencyInfo);
						}
					}
				}
			}
			
		}
	}
	fclose($tempHandler);
	print("<b>DONE</b><br /><br />");

	// BACKUP ESCALATIONS.CFG
	if(file_exists($configuration_path."/escalations.cfg")) {
		?>
		Backing Up escalations.cfg...
		<?php
		copy($configuration_path."/escalations.cfg", $configuration_path."/escalations.cfg.fruity.backup");
		?><b>DONE</b><br />
		<?php
	}
	?>
	Exporting escalations.cfg (Escalations Configuration File)...
	<?php
	$tempHandler = fopen($configuration_path."/escalations.cfg","w");
	fputs($tempHandler, "# Written By Fruity At: " . date("F j, Y, g:i a") . "\n");
	$fruity->get_escalations_list($escalations_list);
	if(count($escalations_list)) {
		foreach($escalations_list as $escalation) {
			unset($serviceInfo);
			$fruity->get_escalation($escalation['escalation_id'], $escalationInfo);
			
			
			// Now we need to get the contact groups for this escalation
			$fruity->return_escalation_contactgroups_list($escalation['escalation_id'], $contactgroups);
			foreach($contactgroups as $contactgroup) {
				if(isset($escalationInfo['contact_groups']))
					$escalationInfo['contact_groups'] .= ",";
				$escalationInfo['contact_groups'] .= $fruity->return_contactgroup_name($contactgroup['contactgroup_id']);
			}
			if(isset($escalationInfo['host_id'])) {	// We're for a host
				$escalationInfo['host_name'] = $fruity->return_host_name($escalationInfo['host_id']);
				unset($escalationInfo['host_id']);
				write_escalation($escalationInfo);
			}
			else if(isset($escalationInfo['host_template_id'])) {	// Uh oh, we've got a depoendency for a host template! AIYEE

				// We need to get a list of hosts which are affected by this template
				$fruity->get_hosts_affected_by_host_template($escalationInfo['host_template_id'], $affectedHosts);
				unset($escalationInfo['host_template_id']);
				if(count($affectedHosts)) {
					foreach($affectedHosts as $host_id) {
						$escalationInfo['host_name'] = $fruity->return_host_name($host_id);
						write_escalation($escalationInfo);
					}
				}
			}
			else if(isset($escalationInfo['service_template_id'])) {
				// We need to get a list of hosts which are affected by this template
				// First get a list of services which are effected
				$fruity->get_services_affected_by_service_template($escalationInfo['service_template_id'], $affectedServices);
				unset($escalationInfo['service_template_id']);
				if(count($affectedServices)) {
					foreach($affectedServices as $service_id) {
						unset($serviceInfo);
						unset($escalationInfo['host_name']);
						unset($escalationInfo['service_description']);
						$fruity->get_service_info($service['service_id'], $serviceInfo);
						if(isset($serviceInfo['host_id'])) {	// We're for a host
							$escalationInfo['host_name'] = $fruity->return_host_name($serviceInfo['host_id']);
							$escalationInfo['service_description'] = $serviceInfo['service_description'];
							write_escalation($escalationInfo);
						}
						else if(isset($serviceInfo['hostgroup_id'])) {	// We're for a hostgroup
							$escalationInfo['hostgroup_name'] = $fruity->return_hostgroup_name($serviceInfo['hostgroup_id']);
							$escalationInfo['service_description'] = $serviceInfo['service_description'];
							unset($serviceInfo['hostgroup_id']);
							write_escalation($escalationInfo);
						}
						else if(isset($serviceInfo['host_template_id'])) {	// Uh oh, we've got a service for a host template! AIYEE
							// We need to get a list of hosts which are affected by this template
							$fruity->get_hosts_affected_by_host_template($serviceInfo['host_template_id'], $affectedHosts);
							$escalationInfo['service_description'] = $serviceInfo['service_description'];
							unset($serviceInfo['host_template_id']);
							if(count($affectedHosts)) {
								foreach($affectedHosts as $host_id) {
									$escalationInfo['host_name'] = $fruity->return_host_name($host_id);
									write_escalation($escalationInfo);
								}
							}
						}
					}
				}
			}
			else if(isset($escalationInfo['service_id'])) {
				$fruity->get_service_info($escalationInfo['service_id'], $serviceInfo);
				$escalationInfo['service_description'] = $serviceInfo['service_description'];
				if(isset($serviceInfo['host_id'])) {	// We're for a host
					$escalationInfo['host_name'] = $fruity->return_host_name($serviceInfo['host_id']);
					unset($serviceInfo['host_id']);
					write_escalation($escalationInfo);
				}
				else if(isset($serviceInfo['hostgroup_id'])) {	// We're for a hostgroup
					$escalationInfo['hostgroup_name'] = $fruity->return_hostgroup_name($serviceInfo['hostgroup_id']);
					unset($serviceInfo['hostgroup_id']);
					write_escalation($escalationInfo);
				}
				else if(isset($serviceInfo['host_template_id'])) {	// Uh oh, we've got a service for a host template! AIYEE
					// We need to get a list of hosts which are affected by this template
					$fruity->get_hosts_affected_by_host_template($serviceInfo['host_template_id'], $affectedHosts);
					$escalationInfo['service_description'] = $serviceInfo['service_description'];
					unset($serviceInfo['host_template_id']);
					if(count($affectedHosts)) {
						foreach($affectedHosts as $host_id) {
							$escalationInfo['host_name'] = $fruity->return_host_name($host_id);
							write_escalation($escalationInfo);
						}
					}
				}
			}
			
		}
	}
	fclose($tempHandler);
	print("<b>DONE</b><br /><br />");
	
	
	print_window_footer();
	?>
	<br />
	<?php
}
print_footer();
?>
